Global discharging methods for coloring problems in graphs - TEL - Thèses en ligne
Author: Marthe Bonamy
Description: This thesis falls within graph theory, and deals more precisely with graph coloring problems. In this thesis, we use and develop the discharging method, a counting argument that makes strong advantage of the graph structure. This method is decisive in the proof of the Four Color Theorem. We first give an illustrated overview of the discharging tools that are used for this work: nice methods that we apply, and handy tricks that we develop. In particular, we present the main ideas in a global discharging argument. In the realm of list edge coloring, we most notably prove that the weak List Coloring Conjecture is true for planar graphs of maximum degree 8 (i.e. that they are edge 9-choosable), thus improving over a result of Borodin from 1990. We finally present our results about square coloring, where the goal is to color the vertices in such a way that two vertices that are adjacent or have a common neighbor receive different colors. We look in particular into sufficient conditions on t [cell cut: 1117 characters, first 1000 kept]
Keywords: graph theory;coloring
Date: 2015/02/09

Accéder directement au contenu

Loading...
Thèse Année : 2015

## Global discharging methods for coloring problems in graphs

## Méthodes de déchargement global pour des problèmes de coloration dans les graphes

Marthe Bonamy (1)
1 ALGCO - Algorithmes, Graphes et Combinatoire
Marthe Bonamy

- Fonction : Auteur
- PersonId : 180516
- IdHAL : marthe-bonamy
- ORCID : 0000-0001-7905-8018
- IdRef : 223311855

Algorithmes, Graphes et Combinatoire

#### Résumé

This thesis falls within graph theory, and deals more precisely with graph coloring problems. In this thesis, we use and develop the discharging method, a counting argument that makes strong advantage of the graph structure. This method is decisive in the proof of the Four Color Theorem. We first give an illustrated overview of the discharging tools that are used for this work: nice methods that we apply, and handy tricks that we develop. In particular, we present the main ideas in a global discharging argument. In the realm of list edge coloring, we most notably prove that the weak List Coloring Conjecture is true for planar graphs of maximum degree 8 (i.e. that they are edge 9-choosable), thus improving over a result of Borodin from 1990. We finally present our results about square coloring, where the goal is to color the vertices in such a way that two vertices that are adjacent or have a common neighbor receive different colors. We look in particular into sufficient conditions on the density of a graph (i.e. the maximum average degree of a subgraph) for its square to be colorable with few colors.
Cette thèse s’inscrit dans le cadre de la théorie des graphes, et porte plus particulièrement sur des problèmes de coloration de graphes. Dans cette thèse, nous nous intéressons à l’utilisation et au développement de la méthode de déchargement, un argument de comptage qui exploite fortement la structure du graphe. Cette méthode est décisive dans la preuve du Théorème des Quatre Couleurs. Nous donnons d’abord une vue d’ensemble des outils de déchargement que nous utilisons dans ce travail, entre les méthodes élégantes mises en application, et les astuces développées. Nous présentons en particulier l’idée essentielle d’une preuve par déchargement global. Dans le cadre de la coloration d’arêtes par liste, nous résolvons la Conjecture de Coloration par Liste faible dans le cas des graphes planaires de degré maximum 8, en prouvant qu’on peut colorier par liste les arêtes de ces derniers avec 9 couleurs seulement. Ceci améliore un résultat de Borodin de 1990. Enfin, nous présentons nos résultats dans le cadre de la coloration de carrés, où il s’agit de colorier les sommets sans qu’il y ait deux sommets adjacents ou avec un voisin commun qui soient de la même couleur. On s’intéresse en particulier à des conditions suffisantes sur la densité du graphe (c-à-d le degré moyen maximum d’un sous-graphe) pour qu’on puisse colorier son carré avec peu de couleurs.

#### Mots clés

graph theory coloring
coloration théorie des graphes

#### Domaines

Mathématique discrète [cs.DM] Combinatoire [math.CO]
Fichier principal
these-mbonamy.pdf (1.37 Mo) Télécharger le fichier

Origine | Fichiers produits par l'(les) auteur(s)

Loading...

Marthe Bonamy : Connectez-vous pour contacter le contributeur

https://theses.hal.science/tel-02083632

Soumis le : vendredi 29 mars 2019-10:34:19

Dernière modification le : lundi 8 avril 2024-13:23:18

Archivage à long terme le : dimanche 30 juin 2019-13:28:05

Télécharger pour visualiser

### Dates et versions

tel-02083632 , version 1 (29-03-2019)

### Identifiants

- HAL Id : tel-02083632 , version 1

### Citer

Marthe Bonamy. Global discharging methods for coloring problems in graphs. Discrete Mathematics [cs.DM]. Université de Montpellier, 2015. English. ⟨NNT : ⟩. ⟨tel-02083632⟩

### Exporter

BibTeX XML-TEI Dublin Core DC Terms EndNote DataCite

### Collections

CNRS ALGCO LIRMM TDS-MACS MIPS UNIV-MONTPELLIER
280 Consultations
780 Téléchargements

### Partager

Gmail Mastodon Facebook X LinkedIn More